@@ -150,14 +150,14 @@ def hex2chr(hex):
 
 if PY2:
     _map2url = {chr(i): chr(i) for i in range(32, 128)}
-    for c in "{}<>;/?:@&=+$%,+":
+    for c in "{}<>;/?@&=+$%,+":
         _map2url[c] = "%" + str(int2hex(ord(c), 2))
     for i in range(128, 256):
         _map2url[chr(i)] = "%" + str(int2hex(i, 2))
     _map2url[chr(32)] = "+"
 else:
     _map2url = {i: unichr(i) for i in range(32, 128)}
-    for c in b"{}<>;/?:@&=+$%,+":
+    for c in b"{}<>;/?@&=+$%,+":
         _map2url[c] = "%" + int2hex(c, 2)
     for i in range(128, 256):
         _map2url[i] = "%" + str(int2hex(i, 2))
@@ -282,11 +282,11 @@ def url_param2value(param):
     for p in param.split("&"):
         if not p:
             continue
-        if p.find("=") == -1:
+        if "=" not in p:
             k = p
             v = True
         else:
-            k, v = p.split("=")
+            k, v = p.split("=", 1)
             k = _decode(k)
             v = _decode(v)
 
@@ -361,13 +361,15 @@ def value2url_param(value):
     elif is_binary(value):
         output = "".join(_map2url[c] for c in value)
     elif is_many(value):
-        output = ",".join(
-            vv for v in value for vv in [value2url_param(v)] if vv or vv == 0
-        )
+        if any(is_data(v) or is_many(v) for v in value):
+            output = _encode(value2json(value))
+        else:
+            output = ",".join(vv for v in value for vv in [value2url_param(v)] if vv or vv == 0)
     else:
         output = _encode(value2json(value))
     return output
 
+
 def is_integer(s):
     if s is True or s is False:
         return False
